@@ -3,6 +3,7 @@ from myst.connectors.model_connectors.extra_trees_regression import ExtraTreesRe
 from myst.connectors.model_connectors.lightgbm import LightGBM
 from myst.connectors.model_connectors.linear_regression import LinearRegression
 from myst.connectors.model_connectors.mlp_regression import MLPRegression
+from myst.connectors.model_connectors.ngboost import NGBoost
 from myst.connectors.model_connectors.random_forest_regression import RandomForestRegression
 from myst.connectors.model_connectors.xgboost import XGBoost
 
@@ -12,6 +13,7 @@ __all__ = [
     "LightGBM",
     "LinearRegression",
     "MLPRegression",
+    "NGBoost",
     "RandomForestRegression",
     "XGBoost",
 ]
