@@ -6,7 +6,7 @@ from myst.openapi.models.time_series_insert_result_get import TimeSeriesInsertRe
 def request_sync(
     client: Client, project_uuid: str, uuid: str, json_body: TimeSeriesInsert
 ) -> TimeSeriesInsertResultGet:
-    """Inserts time series data."""
+    """Manually insert time series data."""
 
     return client.request(
         method="post",
