@@ -1,3 +1,5 @@
+from typing import List
+
 from pydantic import Field
 from typing_extensions import Literal
 
@@ -13,3 +15,4 @@ class HPOResultGet(base_model.BaseModel):
     create_time: str
     metric: Literal["mse"]
     best_trial: HPOTrial
+    trials: List[HPOTrial]
