@@ -328,3 +328,39 @@ def example_hpo_job(example_hpo: Dict[str, Any]) -> Dict[str, Any]:
         creator="626e0364-c334-4148-958b-aeac1ad2d6d6",
         detail="",
     )
+
+
+@pytest.fixture
+def example_model_fit_job(example_project: Dict[str, Any], example_model: Dict[str, Any]) -> Dict[str, Any]:
+    return dict(
+        object="NodeJob",
+        type="ModelFitJob",
+        uuid="c72c0a3d-7690-4b22-bafb-267437a1e649",
+        project=example_project["uuid"],
+        node=example_model["uuid"],
+        state="SUCCESS",
+        create_time="2021-03-17T00:00:09Z",
+        start_time="2021-03-17T00:00:10Z",
+        end_time="2021-03-17T00:03:42Z",
+        as_of_time="2021-03-17T00:00:00Z",
+        result=None,
+        errors=[],
+    )
+
+
+@pytest.fixture
+def example_time_series_run_job(example_project: Dict[str, Any], example_time_series: Dict[str, Any]) -> Dict[str, Any]:
+    return dict(
+        object="NodeJob",
+        type="NodeRunJob",
+        uuid="c72c0a3d-7690-4b22-bafb-267437a1e64a",
+        project=example_project["uuid"],
+        node=example_time_series["uuid"],
+        state="SUCCESS",
+        create_time="2021-03-17T00:00:09Z",
+        start_time="2021-03-17T00:00:10Z",
+        end_time="2021-03-17T00:03:42Z",
+        as_of_time="2021-03-17T00:00:00Z",
+        result=None,
+        errors=[],
+    )
